import { h } from "vue";
import { ElImage, ElTag } from "element-plus";
import { payStatusOptions, statusOptions } from "./_options";
import { DescriptionColumns } from "/@/components/BasicDescriptions";

export const purchpayReliveColumns: DescriptionColumns = [
  {
    field: "returnCode",
    label: "付款解除编号"
  },
  {
    field: "status",
    label: "状态",

    render(status) {
      return h(ElTag, null, {
        default: () =>
          statusOptions.find(s => String(status) === String(s.value))?.label ||
          "--"
      });
    }
  },
  {
    field: "apply_name",
    label: "申请人"
  },
  {
    field: "addtime",
    label: "申请时间"
  },
  {
    field: "apay_fee",
    label: "解除额度"
  },

  {
    field: "returnImg",
    label: "退款回执",
    span: 18,
    render(return_img) {
      const chunks = return_img?.split(",");
      if (!chunks) return null;

      return chunks.map(src => {
        return h(ElImage, {
          src,
          previewSrcList: [src],
          style: {
            height: "20px"
          }
        });
      });
    }
  },

  {
    field: "remark",
    span: 24,
    label: "备注"
  }
];

export const purchpayColumns: DescriptionColumns = [
  {
    field: "dzNo",
    span: 6,
    label: "对账付款编号"
  },
  {
    field: "status",
    label: "状态",
    span: 6,
    render(status) {
      return h(ElTag, null, {
        default: () =>
          payStatusOptions.find(s => String(status) === String(s.value))
            ?.label || "--"
      });
    }
  },

  {
    field: "payNo",
    span: 7,
    label: "对账申请编号"
  },

  {
    field: "apply_name",
    span: 5,
    label: "申请人"
    // render: (apply_name, { apply_id }) =>
    //   createTooltip(apply_name, "申请人ID : " + apply_id, 90)
  },

  {
    field: "pay_fee",
    span: 6,
    label: "付款额度"
  },
  {
    field: "return_time",
    span: 6,
    label: "回执时间"
  },

  {
    field: "return_img",
    label: "付款回执",
    span: 12,
    render(return_img) {
      const chunks = return_img?.split(",");
      if (!chunks) return null;

      return chunks.map(src => {
        return h(ElImage, {
          src,
          previewSrcList: [src],
          style: {
            height: "20px"
          }
        });
      });
    }
  },

  {
    field: "remark",
    label: "备注",
    span: 24
  }
];

export const columns = [
  {
    label: "对账编号",
    prop: "payNo",
    minWidth: 160,
    align: "left"
  },
  {
    label: "卖方公司编号",
    prop: "supplierNo",
    minWidth: 150,
    align: "left"
  },
  {
    label: "买方公司编号",
    prop: "companyNo",
    minWidth: 150
  },
  {
    label: "买方公司名称",
    prop: "companyName",
    minWidth: 180
  },
  {
    label: "总额款",
    prop: "total_fee",
    minWidth: 110,
    align: "total_fee"
  },
  {
    label: "本次付款金额",
    prop: "dpay_fee",
    minWidth: 110,
    align: "left"
  },
  {
    label: "申请人",
    prop: "apply_name",
    minWidth: 90,
    align: "total_fee"
  }
];
