/**
 * 采购回票详情
 */

import { ElImage, ElTag } from "element-plus";
import { h } from "vue";
import { createTooltip } from "/@/utils/tootip";
import { DescriptionColumns } from "/@/components/BasicDescriptions";
import { invTypeOptions, statusOptions } from "./_opitons";
import {
  invoiceTypeList,
  seller_check_type,
  buyer_check_type
} from "/@/utils/status";

export const cgInvTypeOptions = [
  {
    value: "special",
    label: "增值税专用发票"
  },
  {
    value: "normal",
    label: "增值税普通发票"
  },
  {
    value: "roll",
    label: "增值税普通发票（卷式)"
  },
  {
    value: "special_electronic",
    label: "增值税电子专用发票"
  },
  {
    value: "electronic",
    label: "增值税电子普通发票"
  },
  {
    value: "toll",
    label: "增值税电子普通发票（通行费)"
  }
];

export const ticketReturnColumns: DescriptionColumns = [
  {
    field: "hpNo",
    label: "对账回票编号"
  },
  {
    field: "status",
    label: "状态",
    render(data) {
      return h(ElTag, null, {
        default: () => statusOptions.find(s => s.value === String(data))?.label
      });
    }
  },
  {
    field: "apply_name",
    label: "申请人"
  },
  {
    field: "addtime",
    label: "创建时间"
  },

  {
    field: "inv_fee",
    label: "回票金额"
  },

  {
    field: "invType",
    label: "发票上传方式",
    render(data) {
      return h(ElTag, null, {
        default: () => invTypeOptions.find(s => s.value === String(data))?.label
      });
    }
  },
  {
    field: "invoiceType",
    label: "发票类型",
    render(data) {
      return h(ElTag, null, {
        default: () =>
          invoiceTypeList.find(s => s.value === String(data))?.label || "--"
      });
    }
  },

  {
    field: "open_time",
    label: "发票日期"
  },
  {
    field: "invoiceNumber",
    label: "发票号码"
  },
  {
    field: "invoiceCode",
    label: "发票代码"
  },
  {
    field: "inv_subtotal_amount",
    label: "税前总金额"
  },
  {
    field: "inv_amount",
    label: "税后总金额"
  },
  {
    field: "checkNumber",
    span: 8,
    label: "校验码"
  },
  {
    field: "inv_img",
    label: "发票图片",
    span: 4,
    render(src) {
      return h(ElImage, {
        src,
        previewSrcList: [src],
        style: {
          height: "20px"
        }
      });
    }
  },
  {
    field: "remark",
    span: 12,
    label: "审核备注"
  },
  {
    field: "check_remark",
    span: 24,
    label: "发票验证失败原因"
  },
  {
    label: "购买方抬头状态",
    field: "seller_check",
    render(data) {
      return h(
        ElTag,
        {
          type: seller_check_type.find(s => s.value === String(data))
            ?.type as any
        },
        {
          default: () =>
            seller_check_type.find(s => s.value === String(data))?.label || "--"
        }
      );
    }
  },
  {
    label: "销售方抬头状态",
    field: "buyer_check",
    render(data) {
      return h(
        ElTag,
        {
          type: buyer_check_type.find(s => s.value === String(data))
            ?.type as any
        },
        {
          default: () =>
            buyer_check_type.find(s => s.value === String(data))?.label || "--"
        }
      );
    }
  }
];

export const TICKET_INV_COLUMNS = [
  {
    field: "invoiceType",
    span: 1,
    label: "发票类型"
  },
  {
    field: "inv_img",
    span: 1,
    label: "发票图片",
    render(src) {
      return h(ElImage, {
        src,
        previewSrcList: [src],
        style: {
          height: "20px"
        }
      });
    }
  },
  {
    field: "inv_fee",
    span: 2,
    label: "发票税前金额"
  },
  {
    field: "open_time",
    label: "开票时间"
  },
  {
    field: "invoiceNumber",
    label: "发票号码"
  },
  {
    field: "invoiceCode",
    label: "发票代码"
  },
  {
    field: "checkNumber",
    label: "校验码"
  }
];

export const TICKET_COLUMNS = [
  {
    field: "payNo",
    span: 2,
    label: "对账编号"
  },
  {
    field: "hpNo",
    span: 2,
    label: "回票申请编号"
  },
  {
    field: "apply_name",
    label: "申请人",
    span: 2,
    render: (apply_name, { apply_id }) =>
      createTooltip(apply_name, "申请人ID : " + apply_id, 160)
  },
  {
    field: "invType",
    label: "发票申请类型",
    render(data) {
      return h(ElTag, null, {
        default: () => invTypeOptions.find(s => s.value === data)?.label
      });
    }
  },
  {
    field: "status",
    label: "状态",
    render(data) {
      return h(ElTag, null, {
        default: () => statusOptions.find(s => s.value === data)?.label
      });
    }
  },
  {
    field: "total_fee",
    label: "回票总额"
  }
];

export const columns = [
  {
    label: "对账编号",
    prop: "payNo",
    minWidth: 160,
    align: "left"
  },
  {
    label: "供应商编号",
    prop: "supplierNo",
    minWidth: 150,
    align: "left"
  },
  {
    label: "供应商名称",
    prop: "supplierName",
    minWidth: 180,
    align: "left"
  },
  {
    label: "业务公司编号",
    prop: "companyNo",
    minWidth: 150
  },
  {
    label: "业务公司名称",
    prop: "companyName",
    minWidth: 180
  },
  {
    label: "付款状态",
    prop: "pay_status",
    minWidth: 100
  },
  {
    label: "总额款",
    prop: "total_fee",
    minWidth: 110,
    align: "total_fee"
  },
  {
    label: "付款标签金额",
    prop: "pay_tag_fee",
    minWidth: 110,
    align: "left"
  },
  {
    label: "已付款金额",
    prop: "apay_fee",
    minWidth: 110,
    align: "left"
  },
  {
    label: "申请人",
    prop: "apply_name",
    minWidth: 90,
    align: "total_fee"
  }
];

export const ticketFormItems = {
  //手工开票
  "1": [
    {
      label: "发票类型",
      prop: "invoiceType"
    },
    {
      label: "发票代码",
      prop: "invCode"
    },
    {
      label: "发票号码",
      prop: "invNumber"
    },
    {
      label: "税前金额",
      prop: "subtotal_amount"
    },
    {
      label: "校验码",
      prop: "checkNumber"
    },
    {
      label: "开票日期",
      prop: "open_time"
    }
  ],
  //ocr识别
  "2": [
    {
      label: "发票图片",
      prop: "inv_img"
    }
  ]
};
